Fix gcc build on NVCC path (#1661)
* Fix gcc build on NVCC path
* Fix CI build errors
* [dtest] Fix texture and surface obj2D tests
[ROCm/hip commit: e39d7497ec]
This commit is contained in:
committed by
Maneesh Gupta
parent
05ef9bd386
commit
ecdba45d29
@@ -53,7 +53,7 @@ int runTest(int argc, char** argv) {
|
||||
|
||||
hipMemcpyToArray(hipArray, 0, 0, hData, size, hipMemcpyHostToDevice);
|
||||
|
||||
struct hipResourceDesc resDesc;
|
||||
hipResourceDesc resDesc;
|
||||
memset(&resDesc, 0, sizeof(resDesc));
|
||||
resDesc.resType = hipResourceTypeArray;
|
||||
resDesc.res.array.array = hipArray;
|
||||
@@ -62,7 +62,7 @@ int runTest(int argc, char** argv) {
|
||||
hipCreateSurfaceObject(&surfaceObject, &resDesc);
|
||||
|
||||
hipMallocArray(&hipOutArray, &channelDesc, width, height);
|
||||
struct hipResourceDesc resOutDesc;
|
||||
hipResourceDesc resOutDesc;
|
||||
memset(&resOutDesc, 0, sizeof(resOutDesc));
|
||||
resOutDesc.resType = hipResourceTypeArray;
|
||||
resOutDesc.res.array.array = hipOutArray;
|
||||
|
||||
Reference in New Issue
Block a user